#pragma once

// MassBuilderSaveTool
// Copyright (C) 2021-2024 Guillaume Jacquemin
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.

#include <Corrade/Containers/Array.h>
#include <Corrade/Containers/ArrayView.h>
#include <Corrade/Containers/String.h>
#include <Corrade/Containers/StringView.h>

#include <efsw/efsw.hpp>

#include "Backup.h"
#include "../GameObjects/Profile.h"

using namespace Corrade;

namespace mbst { namespace Managers {

class BackupManager {
    public:
        BackupManager();

        auto lastError() -> Containers::StringView;

        void refresh();

        auto backups() const -> Containers::ArrayView<const Backup>;

        bool create(const GameObjects::Profile& profile);
        bool remove(std::size_t index);
        bool restore(std::size_t index);

    private:
        void scanSubdir(Containers::StringView subdir);

        Containers::String _lastError;

        Containers::Array<Backup> _backups;
};

}}
