#pragma once

// MassBuilderSaveTool
// Copyright (C) 2021-2024 Guillaume Jacquemin
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.

#include <cstdint>

#include <string>

#include <Corrade/Containers/Array.h>
#include <Corrade/Containers/String.h>

#include "../GameObjects/Profile.h"

using namespace Corrade;

namespace mbst { namespace Managers {

class ProfileManager {
    public:
        explicit ProfileManager();

        auto ready() const -> bool;
        auto lastError() -> Containers::StringView;

        auto profiles() -> Containers::ArrayView<GameObjects::Profile>;
        bool refreshProfiles();

        auto getProfile(std::size_t index) -> GameObjects::Profile*;
        bool deleteProfile(std::size_t index, bool delete_builds);

    private:
        bool _ready = false;
        Containers::String _lastError;

        Containers::Array<GameObjects::Profile> _profiles;
};

}}
